# Utils with AI support

## Recent Version History

### 1.0.3 (NEXT)

### 1.0.2 (CURRENT)

* Added profiles
* Fixed missing mistralai BUG

### 1.0.1

* Make utils-ai provider agnostic. Support both OpenAI and Mistral.

### 1.0.0

* ChatGPT Chat
* DALL.E Image Generation
